@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Copyright (c) 2017, DIANA-HEP
+# Copyright (c) 2019, IRIS-HEP
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -682,15 +682,22 @@ def _defineclasses(streamerinfos, classes):
                     bases.append(_safename(element._fName))
 
                 elif isinstance(element, TStreamerBasicPointer):
-                    code.append("        if getattr(context, \"speedbump\", True):")
-                    code.append("            cursor.skip(1)")
-
                     assert uproot.const.kOffsetP < element._fType < uproot.const.kOffsetP + 20
                     fType = element._fType - uproot.const.kOffsetP
 
                     dtypename = "_dtype{0}".format(len(dtypes) + 1)
                     dtypes[dtypename] = _ftype2dtype(fType)
-                    code.append("        self._{0} = cursor.array(source, self._{1}, cls.{2})".format(_safename(element._fName), _safename(element._fCountName), dtypename))
+
+                    code.append("        fBasketSeek_dtype = cls.{0}".format(dtypename))
+                    if streamerinfo._fName == b"TBranch" and element._fName == b"fBasketSeek":
+                        code.append("        if getattr(context, \"speedbump\", True):")
+                        code.append("            if cursor.bytes(source, 1)[0] == 2:")
+                        code.append("                fBasketSeek_dtype = numpy.dtype('>i8')")
+                    else:
+                        code.append("        if getattr(context, \"speedbump\", True):")
+                        code.append("            cursor.skip(1)")
+
+                    code.append("        self._{0} = cursor.array(source, self._{1}, fBasketSeek_dtype)".format(_safename(element._fName), _safename(element._fCountName)))
                     fields.append(_safename(element._fName))
                     recarray.append("raise ValueError('not a recarray')")
 
